@@ -6,7 +6,7 @@ use Cwd;
 use Plack::Runner;
 use Term::ANSIColor;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 sub new {
     my $class = shift;
@@ -23,14 +23,19 @@ sub run {
     my @argv = @_;
 
     my $type = $self->_type;   
+    
+    my $middleware = $self->_middleware;
 
     if (exists $type->{module}) {
         push(@argv, '-M');
         push(@argv, $type->{module});
         
         push(@argv, '-e');
-        push(@argv, $type->{eval});          
+        push(@argv, $middleware . '; ' . $type->{eval});                 
     } else {
+        push(@argv, '-e');
+        push(@argv, $middleware);          
+        
         push(@argv, '-a');
         push(@argv, $type->{app});        
     }
@@ -44,6 +49,7 @@ sub run {
     
     my $runner = Plack::Runner->new;    
     $runner->parse_options(@argv);   
+    $runner->prepare_devel($runner);
     $self->_message($runner);
     $runner->run;
 }
@@ -91,6 +97,12 @@ sub _message {
     };     
 }
 
+sub _middleware {
+    my $middleware = 'enable "AccessLog", format => \'%h %l %u %t "%r" %>s %b "%{Referer}i" "%{User-agent}i"\'';
+    
+    return $middleware;
+}
+
 sub _name {
     print STDERR color('bold blue');
     print STDERR "Perl::Server\n\n";    
@@ -99,7 +111,7 @@ sub _name {
 sub _stop {
     print STDERR color('reset');
     print STDERR color('white');    
-    print STDERR "\nHit CTRL-C to stop the perl-server\n";
+    print STDERR "\nHit CTRL-C to stop the perl-server\n\n";
 }
 
 sub _print {
